@@ -31,6 +31,7 @@
 typedef struct parse {
    FILE *fh;
    const char *filename;
+   // ftell() at start of the current line.
    long lpos;
    unsigned int line;
    bool reported_where : 1;
@@ -53,6 +54,9 @@ typedef struct {
 void get_pos(filepos *fp);
 void set_pos(const filepos *fp);
 
+void set_declination_location(real x, real y, real z, const char *proj_str,
+			      filepos *fp);
+
 void skipblanks(void);
 
 /* reads complete data file */
