@@ -38,7 +38,7 @@ class Export3D : public ExportFilter {
 
     ~Export3D();
     const int * passes() const override;
-    void header(const char *, const char *, time_t,
+    void header(const char *, time_t,
 		double, double, double,
 		double, double, double) override;
     void line(const img_point *, const img_point *, unsigned, bool) override;
