@@ -14,12 +14,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #define EXT_SVX_DATA "svx"
 #define EXT_SVX_3D   "3d"
-#define EXT_SVX_3DX  "3dx"
 #define EXT_SVX_ERRS "err"
 #define EXT_SVX_POS  "pos"
 #define EXT_SVX_MSG  "msg"
