@@ -31,21 +31,19 @@ void s_expand_(string *pstr, int addition) {
 }
 
 void
-s_catlen(string* pstr, const char *s, int s_len)
+s_appendlen(string* pstr, const char *s, int s_len)
 {
    if (pstr->capacity - pstr->len < s_len || s_len == 0)
        s_expand_(pstr, s_len);
    memcpy(pstr->s + pstr->len, s, s_len);
    pstr->len += s_len;
-   pstr->s[pstr->len] = '\0';
 }
 
 void
-s_catn(string *pstr, int n, char c)
+s_appendn(string *pstr, int n, char c)
 {
    if (pstr->capacity - pstr->len < n || n == 0)
        s_expand_(pstr, n);
    memset(pstr->s + pstr->len, c, n);
    pstr->len += n;
-   pstr->s[pstr->len] = '\0';
 }
